@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of REANA.
-# Copyright (C) 2018, 2019, 2020, 2021, 2022 CERN.
+# Copyright (C) 2018, 2019, 2020, 2021, 2022, 2023 CERN.
 #
 # REANA is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -12,6 +12,7 @@ import json
 import logging
 import os
 
+import pkg_resources
 import yaml
 
 from reana_commons.errors import REANAConfigDoesNotExist
@@ -39,6 +40,11 @@ class REANAConfig:
         return cls._read_file(cls.config_mapping[kind])
 
 
+reana_yaml_schema_file_path = pkg_resources.resource_filename(
+    __name__, "validation/schemas/reana_analysis_schema.json"
+)
+"""REANA specification schema location."""
+
 REANA_COMPONENT_PREFIX = os.getenv("REANA_COMPONENT_PREFIX", "reana")
 """REANA component naming prefix, i.e. my-prefix-job-controller.
 
@@ -233,51 +239,24 @@ REANA_LOG_FORMAT = os.getenv(
 )
 """REANA components log format."""
 
-CVMFS_REPOSITORIES = {
-    "alice-ocdb.cern.ch": "alice-ocdb",
-    "alice.cern.ch": "alice",
-    "ams.cern.ch": "ams",
-    "atlas-condb.cern.ch": "atlas-condb",
-    "atlas-nightlies.cern.ch": "atlas-nightlies",
-    "atlas.cern.ch": "atlas",
-    "cernvm-prod.cern.ch": "cernvm-prod",
-    "cms-ib.cern.ch": "cms-ib",
-    "cms-opendata-conddb.cern.ch": "cms-opendata-conddb",
-    "cms.cern.ch": "cms",
-    "compass-condb.cern.ch": "compass-condb",
-    "compass.cern.ch": "compass",
-    "cvmfs-config.cern.ch": "cvmfs-config",
-    "fcc.cern.ch": "fcc",
-    "geant4.cern.ch": "geant4",
-    "grid.cern.ch": "grid",
-    "ilc.desy.de": "ilc-desy",
-    "lhcb-condb.cern.ch": "lhcb-condb",
-    "lhcb.cern.ch": "lhcb",
-    "lhcbdev.cern.ch": "lhcbdev",
-    "na61.cern.ch": "na61",
-    "na62.cern.ch": "na62",
-    "projects.cern.ch": "projects",
-    "sft.cern.ch": "sft",
-    "unpacked.cern.ch": "unpacked",
-}
-"""CVMFS repositories available for mounting."""
+REANA_CVMFS_STORAGE_CLASS_NAME = f"{REANA_COMPONENT_PREFIX}-cvmfs"
+"""Name of the StorageClass used to mount CVMFS repositories."""
 
-REANA_CVMFS_PVC_TEMPLATE = {
-    "metadata": {"name": ""},
+REANA_CVMFS_PVC_NAME = f"{REANA_COMPONENT_PREFIX}-cvmfs"
+"""Name of the PersistentVolumeClaim used to mount CVMFS repositories."""
+
+REANA_CVMFS_PVC = {
+    "metadata": {
+        "name": REANA_CVMFS_PVC_NAME,
+        "namespace": REANA_RUNTIME_KUBERNETES_NAMESPACE,
+    },
     "spec": {
         "accessModes": ["ReadOnlyMany"],
-        "storageClassName": "",
-        "resources": {"requests": {"storage": "1G"}},
+        "storageClassName": REANA_CVMFS_STORAGE_CLASS_NAME,
+        "resources": {"requests": {"storage": 1}},
     },
 }
-"""CVMFS persistent volume claim template."""
-
-REANA_CVMFS_SC_TEMPLATE = {
-    "metadata": {"name": ""},
-    "provisioner": "cvmfs.csi.cern.ch",
-    "parameters": {"repository": ""},
-}
-"""CVMFS storage claim template."""
+"""PersistentVolumeClaim used to mount CVMFS repositories."""
 
 INTERACTIVE_SESSION_TYPES = ["jupyter"]
 """List of supported interactive systems."""
@@ -324,11 +303,18 @@ REANA_WORKFLOW_UMASK = 0o0002
 WORKFLOW_RUNTIME_USER_NAME = os.getenv("WORKFLOW_RUNTIME_USER_NAME", "reana")
 """Default OS user name for running job controller."""
 
+WORKFLOW_RUNTIME_GROUP_NAME = os.getenv("WORKFLOW_RUNTIME_GROUP_NAME", "root")
+"""Default OS group name for running job controller."""
+
 WORKFLOW_RUNTIME_USER_UID = os.getenv("WORKFLOW_RUNTIME_USER_UID", 1000)
 """Default user id for running job controller/workflow engine apps & jobs."""
 
 WORKFLOW_RUNTIME_USER_GID = os.getenv("WORKFLOW_RUNTIME_USER_GID", 0)
-"""Default group id for running job controller/workflow engine apps & jobs."""
+"""Default group id for running job controller/workflow engine apps & jobs.
+
+If the group id is changed to a value different than zero, then also the
+`WORKFLOW_RUNTIME_GROUP_NAME` needs to be changed to a value different than `root`.
+"""
 
 REANA_USER_SECRET_MOUNT_PATH = os.getenv(
     "REANA_USER_SECRET_MOUNT_PATH", "/etc/reana/secrets"
@@ -360,6 +346,9 @@ def default_workspace():
 DEFAULT_WORKSPACE_PATH = default_workspace()
 """Default workspace path defined by the admin."""
 
+WORKFLOW_TIME_FORMAT = "%Y-%m-%dT%H:%M:%S"
+"""Time format for workflow starting time, created time etc."""
+
 K8S_CERN_EOS_MOUNT_CONFIGURATION = {
     "volume": {"name": "eos", "hostPath": {"path": "/var/eos"}},
     "volumeMounts": {
@@ -381,6 +370,17 @@ This a configuration set by the system administrators through Helm values at
 cluster creation time.
 """
 
+
+K8S_USE_SECURITY_CONTEXT = (
+    os.getenv("K8S_USE_SECURITY_CONTEXT", "True").lower() == "true"
+)
+"""Whether to use Kubernetes security contexts or not.
+
+This (enabled by default) runs workflows as the WORKFLOW_RUNTIME_USER_UID and
+WORKFLOW_RUNTIME_USER_GID.  It should be set to False for systems (like OpenShift)
+that assign ephemeral UIDs.
+"""
+
 REANA_INFRASTRUCTURE_KUBERNETES_SERVICEACCOUNT_NAME = os.getenv(
     "REANA_INFRASTRUCTURE_KUBERNETES_SERVICEACCOUNT_NAME"
 )
@@ -447,10 +447,49 @@ REANA_COMPUTE_BACKENDS = {
 REANA_WORKFLOW_ENGINES = ["yadage", "cwl", "serial", "snakemake"]
 """Available workflow engines."""
 
-REANA_DEFAULT_SNAKEMAKE_ENV_IMAGE = "snakemake/snakemake:v6.8.0"
+REANA_DEFAULT_SNAKEMAKE_ENV_IMAGE = "docker.io/snakemake/snakemake:v7.32.4"
 """Snakemake default job environment image."""
 
 REANA_JOB_CONTROLLER_CONNECTION_CHECK_SLEEP = float(
     os.getenv("REANA_JOB_CONTROLLER_CONNECTION_CHECK_SLEEP", "10")
 )
 """How many seconds to wait between job controller connection checks."""
+
+COMMAND_DANGEROUS_OPERATIONS = ["sudo ", "cd /"]
+"""Operations in workflow commands considered dangerous."""
+
+# Kerberos configurations
+
+KRB5_CONTAINER_IMAGE = os.getenv(
+    "KRB5_CONTAINER_IMAGE", "docker.io/reanahub/reana-auth-krb5:1.0.1"
+)
+"""Default docker image of KRB5 sidecar container."""
+
+KRB5_INIT_CONTAINER_NAME = "krb5-init"
+"""Name of KRB5 init container."""
+
+KRB5_RENEW_CONTAINER_NAME = "krb5-renew"
+"""Name of KRB5 sidecar container used for ticket renewal."""
+
+KRB5_STATUS_FILE_LOCATION = "/krb5_cache/status_file"
+"""Status file path used to terminate KRB5 renew container when the main
+job finishes."""
+
+KRB5_STATUS_FILE_CHECK_INTERVAL = 15
+"""Time interval in seconds between checks to the status file."""
+
+KRB5_TICKET_RENEW_INTERVAL = 21600  # 6 hours
+"""Time interval in seconds between renewals of the KRB5 ticket."""
+
+KRB5_TOKEN_CACHE_LOCATION = "/krb5_cache/"
+"""Directory of Kerberos tokens cache, shared between job/engine & KRB5 container. It
+should match `default_ccache_name` in krb5.conf.
+"""
+
+KRB5_TOKEN_CACHE_FILENAME = "krb5_{}"
+"""Name of the Kerberos token cache file."""
+
+KRB5_CONFIGMAP_NAME = os.getenv(
+    "REANA_KRB5_CONFIGMAP_NAME", f"{REANA_COMPONENT_PREFIX}-krb5-conf"
+)
+"""Kerberos configMap name."""
