@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of REANA.
-# Copyright (C) 2021 CERN.
+# Copyright (C) 2021, 2022 CERN.
 #
 # REANA is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -10,7 +10,7 @@
 
 import os
 from itertools import filterfalse, chain
-from typing import Any, Dict, List, NoReturn, Optional
+from typing import Any, Dict, List, Optional
 
 from snakemake import snakemake
 from snakemake.dag import DAG
@@ -23,7 +23,9 @@ from snakemake.workflow import Workflow
 from reana_commons.errors import REANAValidationError
 
 
-def snakemake_validate(workflow_file: str, configfiles: List[str]):
+def snakemake_validate(
+    workflow_file: str, configfiles: List[str], workdir: Optional[str] = None
+):
     """Validate Snakemake workflow specification.
 
     :param workflow_file: A specification file compliant with
@@ -31,9 +33,15 @@ def snakemake_validate(workflow_file: str, configfiles: List[str]):
     :type workflow_file: string
     :param configfiles: List of config files paths.
     :type configfiles: List
+    :param workdir: Path to working directory.
+    :type workdir: string or None
     """
     valid = snakemake(
-        snakefile=workflow_file, configfiles=configfiles, dryrun=True, quiet=True,
+        snakefile=workflow_file,
+        configfiles=configfiles,
+        workdir=workdir,
+        dryrun=True,
+        quiet=True,
     )
     if not valid:
         raise REANAValidationError("Snakemake specification is invalid.")
@@ -57,6 +65,9 @@ def snakemake_load(workflow_file: str, **kwargs: Any) -> Dict:
         The code of this function comes from the Snakemake codebase and is adapted
         to fullfil REANA purposes of getting the needed metadata.
 
+        If `workdir` is passed as a keyword argument, then this function will change the
+        CWD to `workdir`.
+
         :param snakefile: Path to Snakefile.
         :type snakefile: string
         :param configfiles: List of config files paths.
@@ -78,14 +89,21 @@ def snakemake_load(workflow_file: str, **kwargs: Any) -> Dict:
             overwrite_config=overwrite_config,
         )
 
-        workflow.include(snakefile=snakefile, overwrite_first_rule=True)
+        workdir = kwargs.get("workdir")
+        if workdir:
+            workflow.workdir(workdir)
+
+        workflow.include(snakefile=snakefile, overwrite_default_target=True)
         workflow.check()
 
         # code copied and adapted from `snakemake.workflow.Workflow.execute()`
         # in order to build the DAG and calculate the job dependencies.
         # https://github.com/snakemake/snakemake/blob/75a544ba528b30b43b861abc0ad464db4d6ae16f/snakemake/workflow.py#L525
         def rules(items):
-            return map(workflow._rules.__getitem__, filter(workflow.is_rule, items),)
+            return map(
+                workflow._rules.__getitem__,
+                filter(workflow.is_rule, items),
+            )
 
         if kwargs.get("keep_target_files"):
 
@@ -95,16 +113,20 @@ def snakemake_load(workflow_file: str, **kwargs: Any) -> Dict:
         else:
 
             def files(items):
-                relpath = (
-                    lambda f: f
-                    if os.path.isabs(f) or f.startswith("root://")
-                    else os.path.relpath(f)
-                )
+                def relpath(f):
+                    return (
+                        f
+                        if os.path.isabs(f) or f.startswith("root://")
+                        else os.path.relpath(f)
+                    )
+
                 return map(relpath, filterfalse(workflow.is_rule, items))
 
         if not kwargs.get("targets"):
             targets = (
-                [workflow.first_rule] if workflow.first_rule is not None else list()
+                [workflow.default_target]
+                if workflow.default_target is not None
+                else list()
             )
 
         prioritytargets = kwargs.get("prioritytargets", [])
@@ -139,18 +161,36 @@ def snakemake_load(workflow_file: str, **kwargs: Any) -> Dict:
             omitrules=omitrules,
         )
 
-        workflow.persistence = Persistence(dag=dag)
+        if hasattr(workflow, "_persistence"):
+            workflow._persistence = Persistence(dag=dag)
+        else:
+            # for backwards compatibility (Snakemake < 7 for Python 3.6)
+            workflow.persistence = Persistence(dag=dag)
         dag.init()
         dag.update_checkpoint_dependencies()
         dag.check_dynamic()
         return dag
 
+    workdir = kwargs.get("workdir")
+    if workdir:
+        workflow_file = os.path.join(workdir, workflow_file)
+
     configfiles = [kwargs.get("input")] if kwargs.get("input") else []
-    snakemake_validate(workflow_file=workflow_file, configfiles=configfiles)
-    snakemake_dag = _create_snakemake_dag(
-        workflow_file, configfiles=configfiles, **kwargs
+
+    snakemake_validate(
+        workflow_file=workflow_file, configfiles=configfiles, workdir=workdir
     )
 
+    # save the cwd to restore it after _create_snakemake_dag, because this function
+    # changes the cwd if `workdir` is in `kwargs`
+    prev_cwd = os.getcwd()
+    try:
+        snakemake_dag = _create_snakemake_dag(
+            workflow_file, configfiles=configfiles, **kwargs
+        )
+    finally:
+        os.chdir(prev_cwd)
+
     job_dependencies = {
         str(job): list(map(str, deps.keys()))
         for job, deps in snakemake_dag.dependencies.items()
@@ -166,6 +206,7 @@ def snakemake_load(workflow_file: str, **kwargs: Any) -> Dict:
                 "params": dict(rule._params),
                 "outputs": dict(rule._output),
                 "commands": [rule.shellcmd],
+                "compute_backend": rule.resources.get("compute_backend"),
                 "kubernetes_memory_limit": rule.resources.get(
                     "kubernetes_memory_limit"
                 ),
