@@ -1,35 +1,36 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of REANA.
-# Copyright (C) 2018, 2019, 2020, 2021 CERN.
+# Copyright (C) 2018, 2019, 2020, 2021, 2022, 2023 CERN.
 #
 # REANA is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 """REANA-Commons utils."""
 
 
+import datetime
 import json
 import logging
 import os
 import platform
 import shutil
+import stat
 import subprocess
+import sys
 import time
 import uuid
 from hashlib import md5
 from pathlib import Path
+from typing import Dict, Optional, Tuple
 
 import click
 import requests
 
+from reana_commons import workspace
 from reana_commons.config import (
-    CVMFS_REPOSITORIES,
-    HTCONDOR_JOB_FLAVOURS,
     REANA_COMPONENT_NAMING_SCHEME,
     REANA_COMPONENT_PREFIX,
     REANA_COMPONENT_TYPES,
-    REANA_CVMFS_PVC_TEMPLATE,
-    REANA_CVMFS_SC_TEMPLATE,
     REANA_JOB_CONTROLLER_CONNECTION_CHECK_SLEEP,
 )
 from reana_commons.errors import REANAMissingWorkspaceError
@@ -62,7 +63,8 @@ def click_table_printer(headers, _filter, data, colours=None):
         if header_indexes:
             row = [row[i] for i in header_indexes]
         click.secho(
-            formatted_output.format(*row), fg=colours[i] if colours else None,
+            formatted_output.format(*row),
+            fg=colours[i] if colours else None,
         )
 
 
@@ -113,13 +115,20 @@ def calculate_job_input_hash(job_spec, workflow_json):
 def calculate_file_access_time(workflow_workspace):
     """Calculate access times of files in workspace."""
     access_times = {}
-    for subdir, dirs, files in os.walk(workflow_workspace):
-        for file in files:
-            file_path = os.path.join(subdir, file)
-            # skip symlinks
-            if os.path.islink(file_path):
-                continue
-            access_times[file_path] = os.stat(file_path).st_atime
+    for file_path in workspace.walk(workflow_workspace, include_dirs=False):
+        try:
+            file_stat = workspace.lstat(workflow_workspace, file_path)
+        except FileNotFoundError:
+            logging.warn(
+                f"Could not get stats of '{file_path}' in '{workflow_workspace}' "
+                "while calculating access times. "
+                "Maybe file was deleted or moved?"
+            )
+            continue
+        if stat.S_ISLNK(file_stat.st_mode):
+            continue
+        full_path = os.path.join(workflow_workspace, file_path)
+        access_times[full_path] = file_stat.st_atime
     return access_times
 
 
@@ -151,20 +160,18 @@ def copy_openapi_specs(output_path, component):
         )
 
 
-def get_workflow_status_change_verb(status):
+def get_workflow_status_change_verb(status: str) -> str:
     """Give the correct verb conjugation depending on status tense.
 
     :param status: String which represents the status the workflow changed to.
     """
-    verb = ""
-    if status.endswith("ing"):
-        verb = "is"
-    elif status.endswith("ed"):
-        verb = "has been"
-    else:
-        raise ValueError("Unrecognised status {}".format(status))
-
-    return verb
+    if status in ("finished", "failed"):
+        return "has"
+    if status in ("created", "stopped", "queued", "deleted"):
+        return "has been"
+    if status in ("running", "pending"):
+        return "is"
+    raise ValueError(f"Unrecognised status {status}")
 
 
 def build_progress_message(
@@ -199,6 +206,38 @@ def build_caching_info_message(
     return caching_info_message
 
 
+def run_command(cmd, display=True, return_output=False, stderr_output=False):
+    """Run given command on shell in the current directory.
+
+    Exit in case of troubles.
+
+    :param cmd: shell command to run
+    :param display: should we display command to run?
+    :param return_output: shall the output of the command be returned?
+    :type cmd: str
+    :type display: bool
+    :type return_output: bool
+    """
+    now = datetime.datetime.now().strftime("%Y-%m-%dT%H:%M:%S")
+    if display:
+        click.secho("[{0}] ".format(now), bold=True, nl=False, fg="green")
+        click.secho("{0}".format(cmd), bold=True)
+    try:
+        if return_output:
+            stderr_flag_val = subprocess.STDOUT if stderr_output else None
+            result = subprocess.check_output(cmd, stderr=stderr_flag_val, shell=True)
+            return result.decode().rstrip("\r\n")
+        else:
+            subprocess.check_call(cmd, shell=True)
+    except subprocess.CalledProcessError as err:
+        if display:
+            click.secho("[{0}] ".format(now), bold=True, nl=False, fg="green")
+            click.secho("{0}".format(err), bold=True, fg="red")
+        if stderr_output:
+            sys.exit(err.output.decode())
+        sys.exit(err.returncode)
+
+
 def remove_upper_level_references(path):
     """Remove upper than `./` references.
 
@@ -292,8 +331,7 @@ def get_disk_usage(
     else:
         command.append("-a")
     if "Darwin" not in platform.system():
-        # Default block size in GNU is KB
-        command.append("-b")
+        command.append("--block-size=1")
 
     name_filter = None
     size_filter = None
@@ -325,52 +363,6 @@ def get_disk_usage(
     return disk_usage_info
 
 
-def render_cvmfs_pvc(cvmfs_volume):
-    """Render REANA_CVMFS_PVC_TEMPLATE."""
-    name = CVMFS_REPOSITORIES[cvmfs_volume]
-    rendered_template = dict(REANA_CVMFS_PVC_TEMPLATE)
-    rendered_template["metadata"]["name"] = "csi-cvmfs-{}-pvc".format(name)
-    rendered_template["spec"]["storageClassName"] = "csi-cvmfs-{}".format(name)
-    return rendered_template
-
-
-def render_cvmfs_sc(cvmfs_volume):
-    """Render REANA_CVMFS_SC_TEMPLATE."""
-    name = CVMFS_REPOSITORIES[cvmfs_volume]
-    rendered_template = dict(REANA_CVMFS_SC_TEMPLATE)
-    rendered_template["metadata"]["name"] = "csi-cvmfs-{}".format(name)
-    rendered_template["parameters"]["repository"] = cvmfs_volume
-    return rendered_template
-
-
-def create_cvmfs_storage_class(cvmfs_volume):
-    """Create CVMFS storage class."""
-    from kubernetes.client.rest import ApiException
-    from reana_commons.k8s.api_client import current_k8s_storagev1_api_client
-
-    try:
-        current_k8s_storagev1_api_client.create_storage_class(
-            render_cvmfs_sc(cvmfs_volume)
-        )
-    except ApiException as e:
-        if e.status != 409:
-            raise e
-
-
-def create_cvmfs_persistent_volume_claim(cvmfs_volume):
-    """Create CVMFS persistent volume claim."""
-    from kubernetes.client.rest import ApiException
-    from reana_commons.k8s.api_client import current_k8s_corev1_api_client
-
-    try:
-        current_k8s_corev1_api_client.create_namespaced_persistent_volume_claim(
-            "default", render_cvmfs_pvc(cvmfs_volume)
-        )
-    except ApiException as e:
-        if e.status != 409:
-            raise e
-
-
 def format_cmd(cmd):
     """Return command in a valid format."""
     if isinstance(cmd, str):
@@ -422,37 +414,33 @@ def build_unique_component_name(component_type, id=None):
     )
 
 
-def check_htcondor_max_runtime(specification):
-    """Check if the field htcondor_max_runtime has a valid input.
+def get_usage_percentage(usage: int, limit: int) -> str:
+    """Usage percentage."""
+    if limit == 0:
+        return ""
+    return "{:.0%}".format(usage / limit)
+
+
+def get_quota_resource_usage(
+    resource: Dict, human_readable_or_raw: str
+) -> Tuple[str, Optional[str]]:
+    """Return quota resource usage and health.
+
+    :param resource: Dict representing quota resource obtained from get_quota_usage()
+    :param human_readable_or_raw: One of ("human_readable", "raw")
+
+    :return: Tuple containing quota resource usage string and resource health.
+        i.e. ("1 MiB out of 10 MiB used (10%)", "healthy")
 
-    :param reana_specification: reana specification of workflow.
     """
-    check_pass = True
-    steps_with_max_runtime = (
-        step
-        for step in specification["steps"]
-        if step.get("htcondor_max_runtime", False)
-    )
-    for i, step in enumerate(steps_with_max_runtime):
-        htcondor_max_runtime = step["htcondor_max_runtime"]
-        if (
-            not str.isdigit(htcondor_max_runtime)
-            and htcondor_max_runtime not in HTCONDOR_JOB_FLAVOURS
-        ):
-            check_pass = False
-            click.secho(
-                "In step {0}:\n'{1}' is not a valid input for htcondor_max_runtime. Inputs must be a digit in the form of a string, or one of the following job flavours: '{2}'.".format(
-                    step.get("name", i),
-                    htcondor_max_runtime,
-                    "' '".join(
-                        [
-                            k
-                            for k, v in sorted(
-                                HTCONDOR_JOB_FLAVOURS.items(), key=lambda key: key[1]
-                            )
-                        ]
-                    ),
-                ),
-                fg="red",
-            )
-    return check_pass
+    usage = resource.get("usage")
+    limit = resource.get("limit")
+    limit_str = ""
+    health = None
+    if limit and limit.get("raw", 0) > 0:
+        health = resource.get("health")
+        percentage = get_usage_percentage(usage.get("raw"), limit.get("raw"))
+        limit_str = f"out of {limit.get(human_readable_or_raw)} used ({percentage})"
+    else:
+        limit_str = "used"
+    return f"{usage[human_readable_or_raw]} {limit_str}", health
