@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of REANA.
-# Copyright (C) 2018 CERN.
+# Copyright (C) 2018, 2019, 2020, 2021, 2023 CERN.
 #
 # REANA is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -9,10 +9,12 @@
 """REANA-Commons utilities testing."""
 
 import os
+import shutil
+import time
 from hashlib import md5
-from pathlib import Path
 
-from pytest import raises
+import pkg_resources
+import pytest
 from pytest_reana.fixtures import sample_workflow_workspace
 
 from reana_commons.utils import (
@@ -21,6 +23,7 @@ from reana_commons.utils import (
     calculate_job_input_hash,
     click_table_printer,
     format_cmd,
+    get_workflow_status_change_verb,
 )
 
 
@@ -65,7 +68,13 @@ def test_calculate_hash_of_dir(sample_workflow_workspace):  # noqa: F811
     """Test calculate_hash_of_dir."""
     non_existing_dir_hash = calculate_hash_of_dir("a/b/c")
     assert non_existing_dir_hash == -1
+
+    test_workspace_path = pkg_resources.resource_filename(
+        "pytest_reana", "test_workspace"
+    )
     sample_workflow_workspace_path = next(sample_workflow_workspace("sample"))
+    shutil.rmtree(sample_workflow_workspace_path)
+    shutil.copytree(test_workspace_path, sample_workflow_workspace_path)
     dir_hash = calculate_hash_of_dir(sample_workflow_workspace_path)
     assert dir_hash == "cb2669b4d7651aa717b6952fce85575f"
     include_only_path = os.path.join(
@@ -78,6 +87,7 @@ def test_calculate_hash_of_dir(sample_workflow_workspace):  # noqa: F811
     empty_dir_hash = calculate_hash_of_dir(sample_workflow_workspace_path, [])
     md5_hash = md5()
     assert empty_dir_hash == md5_hash.hexdigest()
+    shutil.rmtree(sample_workflow_workspace_path)
 
 
 def test_calculate_job_input_hash():
@@ -90,13 +100,23 @@ def test_calculate_job_input_hash():
     ) == calculate_job_input_hash(job_spec_2, workflow_json)
 
 
-def test_calculate_file_access_time(sample_workflow_workspace):  # noqa: F811
+def test_calculate_file_access_time(tmp_path):
     """Test calculate_file_access_time."""
-    sample_workflow_workspace_path = next(sample_workflow_workspace("sample"))
-    access_times = calculate_file_access_time(sample_workflow_workspace_path)
-    all_file_paths = list(Path(sample_workflow_workspace_path).rglob("*.*"))
-    for file_path in all_file_paths:
-        assert str(file_path) in access_times
+    before_writing_files = time.time() - 1
+    tmp_path.joinpath("a.txt").write_text("content of a")
+    tmp_path.joinpath("subdir").mkdir()
+    tmp_path.joinpath("subdir", "b.txt").write_text("content of b")
+    tmp_path.joinpath("c.txt").symlink_to("a.txt")
+    tmp_path.joinpath("another_subdir").mkdir()
+    after_writing_files = time.time() + 1
+
+    access_times = calculate_file_access_time(str(tmp_path))
+
+    assert len(access_times) == 2
+    assert str(tmp_path / "a.txt") in access_times
+    assert str(tmp_path / "subdir" / "b.txt") in access_times
+    for access_time in access_times.values():
+        assert before_writing_files <= access_time <= after_writing_files
 
 
 def test_format_cmd():
@@ -104,5 +124,29 @@ def test_format_cmd():
     test_cmd = "ls -l"
     test_cmd_fail = 12
     assert isinstance(format_cmd(test_cmd), list)
-    with raises(ValueError):
+    with pytest.raises(ValueError):
         format_cmd(test_cmd_fail)
+
+
+@pytest.mark.parametrize(
+    "status,verb",
+    [
+        ("created", "has been"),
+        ("running", "is"),
+        ("finished", "has"),
+        ("failed", "has"),
+        ("deleted", "has been"),
+        ("stopped", "has been"),
+        ("queued", "has been"),
+        ("pending", "is"),
+    ],
+)
+def test_get_workflow_status_change_verb(status, verb):
+    """Test get_workflow_status_change_verb."""
+    assert get_workflow_status_change_verb(status) == verb
+
+
+def test_get_workflow_status_change_verb_invalid():
+    """Test get_workflow_status_change_verb with an invalid status."""
+    with pytest.raises(ValueError, match="invalid"):
+        get_workflow_status_change_verb("invalid")
